@@ -15,8 +15,8 @@ except ImportError:
     colab_env = False
 
 
-EXTENSIONS = ["ms-python.python", "ms-toolsai.jupyter"]
-CODESERVER_VERSION = "3.7.4"
+EXTENSIONS = ["ms-python.python", "ms-toolsai.jupyter", "mechatroner.rainbow-csv", "vscode-icons-team.vscode-icons"]
+CODESERVER_VERSION = "3.10.2"
 
 
 class ColabCode:
@@ -46,9 +46,7 @@ class ColabCode:
 
     @staticmethod
     def _install_code():
-        subprocess.run(
-            ["wget", "https://code-server.dev/install.sh"], stdout=subprocess.PIPE
-        )
+        subprocess.run(["wget", "https://code-server.dev/install.sh"], stdout=subprocess.PIPE)
         subprocess.run(
             ["sh", "install.sh", "--version", f"{CODESERVER_VERSION}"],
             stdout=subprocess.PIPE,
@@ -66,7 +64,7 @@ class ColabCode:
         for tunnel in active_tunnels:
             public_url = tunnel.public_url
             ngrok.disconnect(public_url)
-        url = ngrok.connect(addr=self.port, options={"bind_tls": True})
+        url = ngrok.connect(addr=self.port, bind_tls=True)
         if self._code:
             print(f"Code Server can be accessed on: {url}")
         else:
